# 简介
一个简单的python脚本工具，简化生成OJ数据的过程。  
a script can packer test data for Olympic informatics Online Judge

## 指南
+ 安装: `pip3 install ojpacker`
+ 运行: 直接在终端中输入 `ojpacker`
+ 演示： 运行 `ojpacker demo` 可以生成demo， 详见demo

## 需求 ~~probably~~
+ python版本 >= 3.6.9
+ [rich](https://github.com/willmcgugan/rich) >= 3.0

## 计划中的功能
+ 增加交互式更改设置